@@ -80,6 +80,7 @@ class ORPreRenderPrivate {
                          // pulled from a query source
     QString _wmText;     // the text that is to be rendered as a watermark
     ORDataData _wmData;  // the dynamic source for the watermark text
+    bool _wmUseDefaultFont; // the default font is being used
     QFont   _wmFont;     // the font to use when rendering the _wmText value
                          // on the background of the page. For purposes of
                          // fit, pointSize() of font is ignored and the largest
@@ -150,6 +151,7 @@ ORPreRenderPrivate::ORPreRenderPrivate()
   _wmText = QString::null;
   _wmData.query = QString::null;
   _wmData.column = QString::null;
+  _wmUseDefaultFont = true;
   _wmFont = QFont("Helvetic");
   _wmOpacity = 25;
 
@@ -284,6 +286,7 @@ void ORPreRenderPrivate::renderWatermark(OROPage * p)
     return;
 
   p->setWatermarkText(wmText);
+  p->setWatermarkUseDefaultFont(_wmUseDefaultFont);
   p->setWatermarkFont(_wmFont);
   p->setWatermarkOpacity(_wmOpacity);
 }
@@ -419,27 +422,27 @@ qreal ORPreRenderPrivate::finishCurPage(bool lastPage)
   _subtotContextPageFooter = true;
   if(lastPage && _reportData->pgfoot_last != 0)
   {
-    _yOffset = offset - renderSectionSize(*(_reportData->pgfoot_last));
+    _yOffset = qMax(offset - renderSectionSize(*(_reportData->pgfoot_last)), _yOffset);
     retval = renderSection(*(_reportData->pgfoot_last));
   }
   else if(_pageCounter == 1 && _reportData->pgfoot_first)
   {
-    _yOffset = offset - renderSectionSize(*(_reportData->pgfoot_first));
+    _yOffset = qMax(offset - renderSectionSize(*(_reportData->pgfoot_first)), _yOffset);
     retval = renderSection(*(_reportData->pgfoot_first));
   }
   else if((_pageCounter % 2) == 1 && _reportData->pgfoot_odd)
   {
-    _yOffset = offset - renderSectionSize(*(_reportData->pgfoot_odd));
+    _yOffset = qMax(offset - renderSectionSize(*(_reportData->pgfoot_odd)), _yOffset);
     retval = renderSection(*(_reportData->pgfoot_odd));
   }
   else if((_pageCounter % 2) == 0 && _reportData->pgfoot_even)
   {
-    _yOffset = offset - renderSectionSize(*(_reportData->pgfoot_even));
+    _yOffset = qMax(offset - renderSectionSize(*(_reportData->pgfoot_even)), _yOffset);
     retval = renderSection(*(_reportData->pgfoot_even));
   }
   else if(_reportData->pgfoot_any != 0)
   {
-    _yOffset = offset - renderSectionSize(*(_reportData->pgfoot_any));
+    _yOffset = qMax(offset - renderSectionSize(*(_reportData->pgfoot_any)), _yOffset);
     retval = renderSection(*(_reportData->pgfoot_any));
   }
   _subtotContextPageFooter = false;
@@ -1116,7 +1119,7 @@ qreal ORPreRenderPrivate::renderTextElements(QList<ORObject*> elemList, qreal se
             if (splitter->textBottomRelativePos() > sectionHeight)
                 sectionHeight = splitter->textBottomRelativePos();
 
-            if(splitter->endOfText())
+            if(splitter->endOfText() || _subtotContextPageFooter)
             {
                 splitters.removeAt(i);
                 i--;
@@ -1549,11 +1552,13 @@ ORODocument* ORPreRender::generate()
       if(_internal->_reportData->sections.at(i) != 0)
         _internal->renderDetailSection(*(_internal->_reportData->sections.at(i)));
 
-    qreal rptfootSize = (_internal->_reportData->rptfoot != 0) ? _internal->renderSectionSize(*(_internal->_reportData->rptfoot), true) : 0;
-    if(rptfootSize + _internal->finishCurPageSize(true) + _internal->_bottomMargin + _internal->_yOffset >= _internal->_maxHeight)
-      _internal->createNewPage();
     if(_internal->_reportData->rptfoot != 0)
+    {
+      qreal rptfootSize = (_internal->_reportData->rptfoot != 0) ? _internal->renderSectionSize(*(_internal->_reportData->rptfoot), true) : 0;
+      if(rptfootSize + _internal->finishCurPageSize(true) + _internal->_bottomMargin + _internal->_yOffset >= _internal->_maxHeight)
+        _internal->createNewPage();
       _internal->renderSection(*(_internal->_reportData->rptfoot));
+    }
   }
   _internal->finishCurPage(true);
 
@@ -1622,6 +1627,7 @@ bool ORPreRender::setDom(const QDomDocument & docReport)
       _internal->_wmText = QString::null;
       _internal->_wmData.query = QString::null;
       _internal->_wmData.column = QString::null;
+      _internal->_wmUseDefaultFont = true;
       _internal->_wmFont = QFont("Arial");
       _internal->_wmOpacity = 25;
 
@@ -1635,6 +1641,7 @@ bool ORPreRender::setDom(const QDomDocument & docReport)
           _internal->_wmData.query = _internal->_reportData->wmData.data.query;
           _internal->_wmData.column = _internal->_reportData->wmData.data.column;
         }
+        _internal->_wmUseDefaultFont = _internal->_reportData->wmData.useDefaultFont;
         if(!_internal->_reportData->wmData.useDefaultFont)
           _internal->_wmFont = _internal->_reportData->wmData.font;
         _internal->_wmOpacity = _internal->_reportData->wmData.opacity;
