@@ -29,6 +29,7 @@
 #include <QApplication>
 #include <QSplashScreen>
 #include "dbtools.h"
+#include "builtinSqlFunctions.h"
 #include "xsqlquery.h"
 #include "loginOptions.h"
 #include "login.h"
@@ -209,6 +210,8 @@ void login::sLogin()
     return;
   }
 
+  QSqlQuery().exec(getSqlFromTag("fmt05", db.driverName()));
+
   if (_splash)
   {
     _splash->showMessage(tr("Logging into the Database"));
